core

package
v1.28.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 22, 2026 License: AGPL-3.0 Imports: 17 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func AutoMigrate

func AutoMigrate(db database.Database) error

AutoMigrate runs database migrations This creates all tables from scratch with their FINAL structure For production updates of existing databases, use SQL migration files in /migrations/

func InitDatabase

func InitDatabase(cfg *config.Config) (database.Database, error)

InitDatabase initializes database connection using the database package

func SeedDatabase

func SeedDatabase(ctx context.Context, db database.Database, cfg *config.Config) error

SeedDatabase seeds all necessary initial data This is idempotent - safe to run multiple times

func SetupRouter

func SetupRouter(
	serverConfig *config.ServerConfig,
	authService service.AuthService,
	authHandler *httpHandler.AuthHandler,
	activityHandler *httpHandler.ActivityHandler,
	organizationActivityHandler *httpHandler.OrganizationActivityHandler,
	itemHandler *httpHandler.ItemHandler,
	itemShareHandler *httpHandler.ItemShareHandler,
	excludedDomainHandler *httpHandler.ExcludedDomainHandler,
	userHandler *httpHandler.UserHandler,
	userNotificationPreferencesHandler *httpHandler.UserNotificationPreferencesHandler,
	userAppearancePreferencesHandler *httpHandler.UserAppearancePreferencesHandler,
	userPreferencesHandler *httpHandler.UserPreferencesHandler,
	invitationHandler *httpHandler.InvitationHandler,
	organizationHandler *httpHandler.OrganizationHandler,
	teamHandler *httpHandler.TeamHandler,
	collectionHandler *httpHandler.CollectionHandler,
	organizationItemHandler *httpHandler.OrganizationItemHandler,
	organizationFolderHandler *httpHandler.OrganizationFolderHandler,
	paymentHandler *httpHandler.PaymentHandler,
	webhookHandler *httpHandler.WebhookHandler,
	supportHandler *httpHandler.SupportHandler,
	plansHandler *httpHandler.PlansHandler,
	adminSubscriptionsHandler *httpHandler.AdminSubscriptionsHandler,
	adminMailHandler *httpHandler.AdminMailHandler,
	adminLogsHandler *httpHandler.AdminLogsHandler,
	iconsHandler *httpHandler.IconsHandler,
	ssoHandler *httpHandler.SSOHandler,
	scimHandler *httpHandler.SCIMHandler,
	scimService service.SCIMService,
) *gin.Engine

SetupRouter configures all application routes

Types

type App

type App struct {
	// contains filtered or unexported fields
}

App represents the application

func New

func New(ctx context.Context) (*App, error)

New creates a new application instance with the given context

func (*App) Run

func (a *App) Run(ctx context.Context) error

Run starts the application with the given context

Jump to