Documentation
¶
Index ¶
- func AutoMigrate(db database.Database) error
- func InitDatabase(cfg *config.Config) (database.Database, error)
- func SeedDatabase(ctx context.Context, db database.Database, cfg *config.Config) error
- func SetupRouter(serverConfig *config.ServerConfig, authService service.AuthService, ...) *gin.Engine
- type App
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func AutoMigrate ¶
AutoMigrate runs database migrations This creates all tables from scratch with their FINAL structure For production updates of existing databases, use SQL migration files in /migrations/
func InitDatabase ¶
InitDatabase initializes database connection using the database package
func SeedDatabase ¶
SeedDatabase seeds all necessary initial data This is idempotent - safe to run multiple times
func SetupRouter ¶
func SetupRouter( serverConfig *config.ServerConfig, authService service.AuthService, authHandler *httpHandler.AuthHandler, activityHandler *httpHandler.ActivityHandler, organizationActivityHandler *httpHandler.OrganizationActivityHandler, itemHandler *httpHandler.ItemHandler, itemShareHandler *httpHandler.ItemShareHandler, excludedDomainHandler *httpHandler.ExcludedDomainHandler, userHandler *httpHandler.UserHandler, userNotificationPreferencesHandler *httpHandler.UserNotificationPreferencesHandler, userAppearancePreferencesHandler *httpHandler.UserAppearancePreferencesHandler, userPreferencesHandler *httpHandler.UserPreferencesHandler, invitationHandler *httpHandler.InvitationHandler, organizationHandler *httpHandler.OrganizationHandler, teamHandler *httpHandler.TeamHandler, collectionHandler *httpHandler.CollectionHandler, organizationItemHandler *httpHandler.OrganizationItemHandler, organizationFolderHandler *httpHandler.OrganizationFolderHandler, paymentHandler *httpHandler.PaymentHandler, webhookHandler *httpHandler.WebhookHandler, supportHandler *httpHandler.SupportHandler, plansHandler *httpHandler.PlansHandler, adminSubscriptionsHandler *httpHandler.AdminSubscriptionsHandler, adminMailHandler *httpHandler.AdminMailHandler, adminLogsHandler *httpHandler.AdminLogsHandler, iconsHandler *httpHandler.IconsHandler, ssoHandler *httpHandler.SSOHandler, scimHandler *httpHandler.SCIMHandler, scimService service.SCIMService, ) *gin.Engine
SetupRouter configures all application routes
Types ¶
Click to show internal directories.
Click to hide internal directories.